_Developer's notes for Sanli_

## Wishlist to develop
* [ ] easy game with mouse clicks
* [ ] test and document using an arduino
* [ ] test and document using the digilent

### Nice to have
* [ ] webcam control 

## Questions for Aquiles
* where to add long description?
* how to credit Aquiles in authors?
* what is the logic of directories for start files?

## Project roadmap
- make simple package with easy installation
- make docs on aims and scope of the project
- write how to contribute
- make simple presentation for first time users
- make list of initiatives and ongoing projects

## tricks to explain
- explain python setup.py -develop, makes packages available
- use sys.path.append (folder) as simplest method to include the 